@@ -20,7 +20,7 @@ impl fmt::Debug for Debug<'_> {
 }
 
 impl DiscovererSubtitleInfo {
-    pub fn debug(&self) -> Debug {
+    pub fn debug(&self) -> Debug<'_> {
         Debug(self)
     }
 }
